@@ -2,26 +2,62 @@
 import itertools
 import os
 import re
-from typing import Dict, List, Optional, Tuple
+from typing import Dict, List, Optional, Tuple, Iterable
 
 import sympy as sp
+from sympy.codegen.rewriting import optimize, Optimization
 from sympy.printing.cxx import CXX11CodePrinter
 from sympy.utilities.iterables import numbered_symbols
 from toposort import toposort
 
 
 class AmiciCxxCodePrinter(CXX11CodePrinter):
-    """C++ code printer"""
+    """
+    C++ code printer
+
+    Attributes
+    ----------
+    extract_cse:
+        Whether to extract common subexpression during code printing.
+        Currently controlled by environment variable ``AMICI_EXTRACT_CSE``.
+    optimizations:
+        Iterable of :class:`sympy.codegen.rewriting.Optimization`s to optimize
+        generated code (e.g. :data:`sympy.codegen.rewriting.Optimization` for
+        optimizations, such as ``log(1 + x)`` --> ``logp1(x)``).
+        Applying these optimizations is potentially quite costly.
+    """
+
+    optimizations: Iterable[Optimization] = ()
 
     def __init__(self):
+        """
+        Create code printer
+
+        :param optimize_code:
+            Whether to apply code optimizations such as log(1 + x) --> logp1(x)
+        """
         super().__init__()
 
         # extract common subexpressions in matrix functions?
         self.extract_cse = (os.getenv("AMICI_EXTRACT_CSE", "0").lower()
                             in ('1', 'on', 'true'))
 
+        # Floating-point optimizations
+        # e.g., log(1 + x) --> logp1(x)
+        if self.optimizations:
+            self._fpoptimizer = lambda x: optimize(x, self.optimizations)
+        else:
+            self._fpoptimizer = None
+
     def doprint(self, expr: sp.Expr, assign_to: Optional[str] = None) -> str:
+        if self._fpoptimizer:
+            if isinstance(expr, list):
+                expr = list(map(self._fpoptimizer, expr))
+            else:
+                expr = self._fpoptimizer(expr)
+
         try:
+            # floating point
             code = super().doprint(expr, assign_to)
             code = re.sub(r'(^|\W)M_PI(\W|$)', r'\1amici::pi\2', code)
 
@@ -214,8 +250,8 @@ class AmiciCxxCodePrinter(CXX11CodePrinter):
 
                 symbol_row_vals.append(row)
                 idx += 1
-                symbol_name = f'd{self.doprint(rownames[row])}' \
-                              f'_d{self.doprint(colnames[col])}'
+                symbol_name = f'd{rownames[row].name}' \
+                              f'_d{colnames[col].name}'
                 if identifier:
                     symbol_name += f'_{identifier}'
                 symbol_list.append(symbol_name)
